@@ -375,7 +375,7 @@ my $var = {
 	_one_character                 => '1',
 	_one_pixel                     => '1',
 	_one_pixel_borderwidth         => '1',
-	_program_title                 => 'SeismicUnixGui V0.85.5',
+	_program_title                 => 'SeismicUnixGui V0.87.0',
 	_project_selector_title        => 'Project Selector',
 	_l_suplot_title                => 'L_suplot',
 	_project_selector_title        => 'Project Selector',
@@ -709,6 +709,7 @@ sub get_developer_sunix_category_h {
 		_sugprfb => $developer_sunix_categories[11],
 		_sukill  => $developer_sunix_categories[11],
 		_sumute  => $developer_sunix_categories[11],
+		_suramp  => $developer_sunix_categories[11],
 		_supad   => $developer_sunix_categories[11],
 		_susort  => $developer_sunix_categories[11],
 		_susplit => $developer_sunix_categories[11],
@@ -862,8 +863,9 @@ my @sunix_plot_programs = (
 );
 
 my @sunix_shapeNcut_programs = (
-	"suflip",  "sugain", "sugprfb", "sukill", "sumute", "susort",
-	"susplit", "suwind", "supad",   "suvcat",
+	"suflip", "sugain", "sugprfb", "sukill", "sumute", "susort",
+	"suramp",
+	"susplit", "suwind", "supad", "suvcat",
 );
 
 my @sunix_statsMath_programs = (
