@@ -4,8 +4,8 @@
 
 =head2 SYNOPSIS
 
-PACKAGE NAME:  supswigp - PostScript Bit-mapped WIGgle plot of a segy data set	
-AUTHOR: Juan Lorenzo
+PERL PROGRAM NAME:  supswigp - PostScript Bit-mapped WIGgle plot of a segy data set	
+AUTHOR: Juan Lorenzo (Perl module only)
 DATE:   
 DESCRIPTION:
 Version: 
